@@ -57,8 +57,6 @@ static void print_version(void)
     nv_info_msg(TAB, "This program is used to manipulate X configuration files, "
                      "specifically to enable NVIDIA X driver functionality.");
     nv_info_msg(NULL, "");
-    nv_info_msg(TAB, "Copyright (C) 2005 - 2010 NVIDIA Corporation.");
-    nv_info_msg(NULL, "");
 } /* print_version() */
 
 
@@ -335,7 +333,7 @@ static void parse_commandline(Options *op, int argc, char *argv[])
                 break;
             }
 
-            if (intval < 0 || intval > 13) {
+            if (intval < 0 || intval > 14) {
                 fprintf(stderr, "\n");
                 fprintf(stderr, "Invalid stereo: %d.\n", intval);
                 fprintf(stderr, "\n");
@@ -538,10 +536,6 @@ static void parse_commandline(Options *op, int argc, char *argv[])
                 break;
             }
 
-        case LOGO_PATH_OPTION:
-            op->logo_path = disable ? NV_DISABLE_STRING_OPTION : strval;
-            break;
-  
         case USE_DISPLAY_DEVICE_OPTION:
             op->use_display_device = 
                 disable ? NV_DISABLE_STRING_OPTION : strval;
@@ -620,6 +614,20 @@ static void parse_commandline(Options *op, int argc, char *argv[])
             op->num_x_screens = intval;
             break;
 
+        case FORCE_COMPOSITION_PIPELINE_OPTION:
+            op->force_composition_pipeline =
+                disable ? NV_DISABLE_STRING_OPTION : strval;
+            break;
+
+        case FORCE_FULL_COMPOSITION_PIPELINE_OPTION:
+            op->force_full_composition_pipeline =
+                disable ? NV_DISABLE_STRING_OPTION : strval;
+            break;
+
+        case ALLOW_HMD_OPTION:
+            op->allow_hmd = disable ? NV_DISABLE_STRING_OPTION : strval;
+            break;
+
         default:
             goto fail;
         }
