@@ -31,7 +31,6 @@
 
 
 /* Boolean options */
-#define NOLOGO_BOOL_OPTION                      0
 #define UBB_BOOL_OPTION                         1
 #define RENDER_ACCEL_BOOL_OPTION                2
 #define NO_RENDER_EXTENSION_BOOL_OPTION         3
@@ -60,16 +59,15 @@
 #define INCLUDE_IMPLICIT_METAMODES_BOOL_OPTION  34
 #define USE_EVENTS_BOOL_OPTION                  35
 #define CONNECT_TO_ACPID_BOOL_OPTION            36
-#define ENABLE_ACPI_HOTKEYS_BOOL_OPTION         37
-#define MODE_DEBUG_BOOL_OPTION                  38
-#define THERMAL_CONFIGURATION_CHECK_BOOL_OPTION 39
-#define PRESERVE_BUSID_BOOL_OPTION              40
-#define BASE_MOSAIC_BOOL_OPTION                 41
-#define ALLOW_EMPTY_INITIAL_CONFIGURATION       42
-#define DELETE_UNUSED_DP12_DPYS                 43
-#define INBAND_STEREO_SIGNALING                 44
+#define MODE_DEBUG_BOOL_OPTION                  37
+#define THERMAL_CONFIGURATION_CHECK_BOOL_OPTION 38
+#define PRESERVE_BUSID_BOOL_OPTION              39
+#define BASE_MOSAIC_BOOL_OPTION                 40
+#define ALLOW_EMPTY_INITIAL_CONFIGURATION       41
+#define INBAND_STEREO_SIGNALING                 42
+#define FORCE_YUV_420                           43
 
-#define XCONFIG_BOOL_OPTION_COUNT (INBAND_STEREO_SIGNALING + 1)
+#define XCONFIG_BOOL_OPTION_COUNT (FORCE_YUV_420 + 1)
 
 /* # of 32-bit variables needed to hold all the boolean options (bits) */
 #define XCONFIG_BOOL_OPTION_SLOTS  \
@@ -138,7 +136,6 @@ typedef struct __options {
     char *extract_edids_from_file;
     char *extract_edids_output_file;
     char *nvidia_xinerama_info_order;
-    char *logo_path;
     char *metamode_orientation;
     char *use_display_device;
     char *custom_edid;
@@ -154,6 +151,10 @@ typedef struct __options {
     char *flatpanel_properties;
     char *nvidia_3dvision_usb_path;
     char *nvidia_3dvisionpro_config_file;
+    char *force_composition_pipeline;
+    char *force_full_composition_pipeline;
+    char *allow_hmd;
+
     double tv_over_scan;
 
     struct {
@@ -198,8 +199,6 @@ typedef struct {
 
 int copy_file(const char *srcfile, const char *dstfile, mode_t mode);
 
-int directory_exists(const char *dir);
-
 /* make_usable.c */
 
 int update_modules(XConfigPtr config);
